ElementAttributes constructor

ElementAttributes(
  1. int index,
  2. int row,
  3. int position,
  4. Color elementColor, {
  5. Color? parentColor,
  6. String? description,
})

Describes the parameters for each dot of the Assembly :

• index is the increasing index starting at 0 for the dots from left to right.

• row is the row of the assembly from inside to outside.

• position is the position in thee row from left to right.

• elementColor is the dot color displayed in full opacity by default ; if parentColor is provided, the opacity is dimmed if matching, full if divergent.

• description is a nullable String that is NOT YET displayed ; for future use.

Implementation

ElementAttributes(this.index, this.row, this.position, this.elementColor,
    {this.parentColor, this.description});