SectorAttributes constructor

SectorAttributes(
  1. int index,
  2. int size,
  3. Color? elementColor, {
  4. String? description,
})

Describes the parameters for each sector of the surrounding arc around the votes :

• index is the increasing index starting at 0 for the sectors from left to right.

• size is the size of the sector (i.e the number of members involved).

• elementColor is the dot color displayed in full opacity by default.

• description is a nullable String that is NOT YET displayed ; for future use.

Implementation

SectorAttributes(this.index, this.size, this.elementColor,
    {this.description});